@@ -5,7 +5,7 @@ from typing import ClassVar
 
 from pyplumio.const import ATTR_PASSWORD, FrameType
 from pyplumio.frames import Response
-from pyplumio.helpers.typing import DeviceDataType, MessageType
+from pyplumio.helpers.typing import EventDataType, MessageType
 from pyplumio.structures.alerts import AlertsStructure
 from pyplumio.structures.data_schema import DataSchemaStructure
 from pyplumio.structures.ecomax_parameters import EcomaxParametersStructure
@@ -27,11 +27,11 @@ class ProgramVersionResponse(Response):
 
     frame_type: ClassVar[int] = FrameType.RESPONSE_PROGRAM_VERSION
 
-    def create_message(self, data: DeviceDataType) -> MessageType:
+    def create_message(self, data: EventDataType) -> MessageType:
         """Create frame message."""
         return ProgramVersionStructure(self).encode(data)
 
-    def decode_message(self, message: MessageType) -> DeviceDataType:
+    def decode_message(self, message: MessageType) -> EventDataType:
         """Decode frame message."""
         return ProgramVersionStructure(self).decode(message)[0]
 
@@ -43,11 +43,11 @@ class DeviceAvailableResponse(Response):
 
     frame_type: ClassVar[int] = FrameType.RESPONSE_DEVICE_AVAILABLE
 
-    def create_message(self, data: DeviceDataType) -> MessageType:
+    def create_message(self, data: EventDataType) -> MessageType:
         """Create frame message."""
         return NetworkInfoStructure(self).encode(data)
 
-    def decode_message(self, message: MessageType) -> DeviceDataType:
+    def decode_message(self, message: MessageType) -> EventDataType:
         """Decode frame message."""
         return NetworkInfoStructure(self).decode(message, offset=1)[0]
 
@@ -57,11 +57,11 @@ class UIDResponse(Response):
 
     frame_type: ClassVar[int] = FrameType.RESPONSE_UID
 
-    def create_message(self, data: DeviceDataType) -> MessageType:
+    def create_message(self, data: EventDataType) -> MessageType:
         """Create frame message."""
         return ProductInfoStructure(self).encode(data)
 
-    def decode_message(self, message: MessageType) -> DeviceDataType:
+    def decode_message(self, message: MessageType) -> EventDataType:
         """Decode frame message."""
         return ProductInfoStructure(self).decode(message, offset=3)[0]
 
@@ -71,7 +71,7 @@ class PasswordResponse(Response):
 
     frame_type: ClassVar[int] = FrameType.RESPONSE_PASSWORD
 
-    def decode_message(self, message: MessageType) -> DeviceDataType:
+    def decode_message(self, message: MessageType) -> EventDataType:
         """Decode frame message."""
         password = message[1:].decode() if message[1:] else None
         return {ATTR_PASSWORD: password}
@@ -84,11 +84,11 @@ class EcomaxParametersResponse(Response):
 
     frame_type: ClassVar[int] = FrameType.RESPONSE_ECOMAX_PARAMETERS
 
-    def create_message(self, data: DeviceDataType) -> MessageType:
+    def create_message(self, data: EventDataType) -> MessageType:
         """Create frame message."""
         return EcomaxParametersStructure(self).encode(data)
 
-    def decode_message(self, message: MessageType) -> DeviceDataType:
+    def decode_message(self, message: MessageType) -> EventDataType:
         """Decode frame message."""
         return EcomaxParametersStructure(self).decode(message)[0]
 
@@ -100,7 +100,7 @@ class MixerParametersResponse(Response):
 
     frame_type: ClassVar[int] = FrameType.RESPONSE_MIXER_PARAMETERS
 
-    def decode_message(self, message: MessageType) -> DeviceDataType:
+    def decode_message(self, message: MessageType) -> EventDataType:
         """Decode frame message."""
         return MixerParametersStructure(self).decode(message)[0]
 
@@ -112,7 +112,7 @@ class ThermostatParametersResponse(Response):
 
     frame_type: ClassVar[int] = FrameType.RESPONSE_THERMOSTAT_PARAMETERS
 
-    def decode_message(self, message: MessageType) -> DeviceDataType:
+    def decode_message(self, message: MessageType) -> EventDataType:
         """Decode frame message."""
         return {ATTR_THERMOSTAT_PARAMETERS_DECODER: ThermostatParametersStructure(self)}
 
@@ -124,7 +124,7 @@ class DataSchemaResponse(Response):
 
     frame_type: ClassVar[int] = FrameType.RESPONSE_DATA_SCHEMA
 
-    def decode_message(self, message: MessageType) -> DeviceDataType:
+    def decode_message(self, message: MessageType) -> EventDataType:
         """Decode frame message."""
         return DataSchemaStructure(self).decode(message)[0]
 
@@ -167,7 +167,7 @@ class AlertsResponse(Response):
 
     frame_type: ClassVar[int] = FrameType.RESPONSE_ALERTS
 
-    def decode_message(self, message: MessageType) -> DeviceDataType:
+    def decode_message(self, message: MessageType) -> EventDataType:
         """Decode frame message."""
         return AlertsStructure(self).decode(message)[0]
 
@@ -177,6 +177,6 @@ class SchedulesResponse(Response):
 
     frame_type: ClassVar[int] = FrameType.RESPONSE_SCHEDULES
 
-    def decode_message(self, message: MessageType) -> DeviceDataType:
+    def decode_message(self, message: MessageType) -> EventDataType:
         """Decode frame message."""
         return SchedulesStructure(self).decode(message)[0]
