@@ -5,10 +5,10 @@ from abc import ABC, abstractmethod
 from dataclasses import dataclass
 
 from pyplumio.frames import Frame
-from pyplumio.helpers.typing import DeviceDataType
+from pyplumio.helpers.typing import EventDataType
 
 
-def ensure_device_data(data: DeviceDataType | None, *args) -> DeviceDataType:
+def ensure_device_data(data: EventDataType | None, *args) -> EventDataType:
     """Make new or merge multiple device data."""
     if data is None:
         data = {}
@@ -30,7 +30,7 @@ class Structure(ABC, StructureDataClass):
     """Represents data structure."""
 
     @abstractmethod
-    def encode(self, data: DeviceDataType) -> bytearray:
+    def encode(self, data: EventDataType) -> bytearray:
         """Encode device data to bytearray message."""
 
     @abstractmethod
@@ -38,20 +38,20 @@ class Structure(ABC, StructureDataClass):
         self,
         message: bytearray,
         offset: int = 0,
-        data: DeviceDataType | None = None,
-    ) -> tuple[DeviceDataType, int]:
+        data: EventDataType | None = None,
+    ) -> tuple[EventDataType, int]:
         """Decode bytes and return message data and offset."""
 
 
 class StructureDecoder(Structure, ABC):
     """Represent structure that only handles decoding."""
 
-    def encode(self, data: DeviceDataType) -> bytearray:
+    def encode(self, data: EventDataType) -> bytearray:
         """Encode device data to bytearray message."""
         return bytearray()
 
     @abstractmethod
     def decode(
-        self, message: bytearray, offset: int = 0, data: DeviceDataType | None = None
-    ) -> tuple[DeviceDataType, int]:
+        self, message: bytearray, offset: int = 0, data: EventDataType | None = None
+    ) -> tuple[EventDataType, int]:
         """Decode bytes and return message data and offset."""
