@@ -6,7 +6,7 @@ from typing import Final
 
 from pyplumio import util
 from pyplumio.const import BYTE_UNDEFINED
-from pyplumio.helpers.typing import DeviceDataType
+from pyplumio.helpers.typing import EventDataType
 from pyplumio.structures import StructureDecoder, ensure_device_data
 
 ATTR_LAMBDA_STATE: Final = "lambda_state"
@@ -18,8 +18,8 @@ class LambaSensorStructure(StructureDecoder):
     """Represents lambda sensor data structure."""
 
     def decode(
-        self, message: bytearray, offset: int = 0, data: DeviceDataType | None = None
-    ) -> tuple[DeviceDataType, int]:
+        self, message: bytearray, offset: int = 0, data: EventDataType | None = None
+    ) -> tuple[EventDataType, int]:
         """Decode bytes and return message data and offset."""
         if message[offset] == BYTE_UNDEFINED:
             return ensure_device_data(data), offset + 1
