@@ -4,7 +4,7 @@ from __future__ import annotations
 from typing import Final
 
 from pyplumio.const import BYTE_UNDEFINED
-from pyplumio.helpers.typing import DeviceDataType
+from pyplumio.helpers.typing import EventDataType
 from pyplumio.structures import StructureDecoder, ensure_device_data
 
 ATTR_LOAD: Final = "load"
@@ -14,8 +14,8 @@ class LoadStructure(StructureDecoder):
     """Represents load sensor data structure."""
 
     def decode(
-        self, message: bytearray, offset: int = 0, data: DeviceDataType | None = None
-    ) -> tuple[DeviceDataType, int]:
+        self, message: bytearray, offset: int = 0, data: EventDataType | None = None
+    ) -> tuple[EventDataType, int]:
         """Decode bytes and return message data and offset."""
         if message[offset] == BYTE_UNDEFINED:
             return ensure_device_data(data), offset + 1
