@@ -6,7 +6,7 @@ from typing import Final
 
 from pyplumio import util
 from pyplumio.const import ATTR_CURRENT_TEMP, ATTR_TARGET_TEMP
-from pyplumio.helpers.typing import DeviceDataType
+from pyplumio.helpers.typing import EventDataType
 from pyplumio.structures import StructureDecoder, ensure_device_data
 
 ATTR_PUMP: Final = "pump"
@@ -18,16 +18,16 @@ class MixerSensorsStructure(StructureDecoder):
     """Represents mixers data structure."""
 
     def decode(
-        self, message: bytearray, offset: int = 0, data: DeviceDataType | None = None
-    ) -> tuple[DeviceDataType, int]:
+        self, message: bytearray, offset: int = 0, data: EventDataType | None = None
+    ) -> tuple[EventDataType, int]:
         """Decode bytes and return message data and offset."""
         mixer_count = message[offset]
         offset += 1
-        mixer_sensors: list[tuple[int, DeviceDataType]] = []
+        mixer_sensors: list[tuple[int, EventDataType]] = []
         for index in range(mixer_count):
             current_temp = util.unpack_float(message[offset : offset + 4])[0]
             if not math.isnan(current_temp):
-                sensors: DeviceDataType = {}
+                sensors: EventDataType = {}
                 sensors[ATTR_CURRENT_TEMP] = current_temp
                 sensors[ATTR_TARGET_TEMP] = message[offset + 4]
                 outputs = message[offset + 6]
