@@ -2,6 +2,7 @@
 
 import asyncio
 from unittest.mock import AsyncMock, Mock, call, patch
+import warnings
 
 import pytest
 
@@ -12,7 +13,6 @@ from pyplumio.const import (
     ATTR_OFFSET,
     ATTR_PARAMETER,
     ATTR_SCHEDULE,
-    ATTR_SENSORS,
     ATTR_SIZE,
     ATTR_SWITCH,
     ATTR_TYPE,
@@ -53,8 +53,9 @@ from pyplumio.frames.responses import (
     ThermostatParametersResponse,
 )
 from pyplumio.helpers.network_info import NetworkInfo
+from pyplumio.helpers.parameter import Parameter
 from pyplumio.helpers.schedule import Schedule
-from pyplumio.helpers.typing import DeviceDataType
+from pyplumio.helpers.typing import EventDataType
 from pyplumio.structures.ecomax_parameters import (
     ATTR_ECOMAX_CONTROL,
     EcomaxBinaryParameter,
@@ -66,7 +67,7 @@ from pyplumio.structures.mixer_parameters import (
     MixerBinaryParameter,
     MixerParameter,
 )
-from pyplumio.structures.regulator_data import ATTR_REGDATA
+from pyplumio.structures.regulator_data import ATTR_REGDATA, RegulatorData
 from pyplumio.structures.schedules import (
     ATTR_SCHEDULE_PARAMETER,
     ATTR_SCHEDULE_SWITCH,
@@ -104,39 +105,95 @@ def test_ecoster(ecoster: EcoSTER) -> None:
     assert isinstance(ecoster, EcoSTER)
 
 
+async def test_deprecated_get_value(ecomax: EcoMAX) -> None:
+    """Test deprecated get_value method."""
+    mock_parameter = Mock(spec=Parameter)
+    with patch(
+        "pyplumio.devices.Device.get",
+        new_callable=AsyncMock,
+        side_effect=(None, mock_parameter),
+    ) as mock_get, warnings.catch_warnings(record=True) as warn:
+        warnings.simplefilter("always")
+        assert await ecomax.get_value("test") is None
+        assert await ecomax.get_value("test") == mock_parameter.value
+        assert len(warn) == 2
+        assert issubclass(warn[-1].category, DeprecationWarning)
+        assert "deprecated" in str(warn[-1].message)
+        mock_get.assert_any_await("test", None)
+
+
+async def test_deprecated_get_parameter(ecomax: EcoMAX) -> None:
+    """Test deprecated get_parameter method."""
+    with patch(
+        "pyplumio.devices.Device.get", new_callable=AsyncMock
+    ) as mock_get, warnings.catch_warnings(record=True) as warn:
+        warnings.simplefilter("always")
+        await ecomax.get_parameter("test")
+        assert len(warn) == 1
+        assert issubclass(warn[-1].category, DeprecationWarning)
+        assert "deprecated" in str(warn[-1].message)
+        mock_get.assert_awaited_once_with("test", None)
+
+
+async def test_deprecated_set_value(ecomax: EcoMAX) -> None:
+    """Test deprecated set_value method."""
+    with patch(
+        "pyplumio.devices.Device.set", new_callable=AsyncMock
+    ) as mock_set, warnings.catch_warnings(record=True) as warn:
+        warnings.simplefilter("always")
+        await ecomax.set_value("test", 1)
+        assert len(warn) == 1
+        assert issubclass(warn[-1].category, DeprecationWarning)
+        assert "deprecated" in str(warn[-1].message)
+        mock_set.assert_awaited_once_with("test", 1, None)
+
+
+def test_deprecated_set_value_nowait(ecomax: EcoMAX) -> None:
+    """Test deprecated set_value_nowait method."""
+    with patch(
+        "pyplumio.devices.Device.set_nowait"
+    ) as mock_set_nowait, warnings.catch_warnings(record=True) as warn:
+        warnings.simplefilter("always")
+        ecomax.set_value_nowait("test", 1)
+        assert len(warn) == 1
+        assert issubclass(warn[-1].category, DeprecationWarning)
+        assert "deprecated" in str(warn[-1].message)
+        mock_set_nowait.assert_called_once_with("test", 1, None)
+
+
 async def test_async_setup() -> None:
     """Test requesting initial data frames."""
     ecomax = EcoMAX(asyncio.Queue(), network=NetworkInfo())
 
-    with patch(
-        "pyplumio.devices.ecomax.EcoMAX.make_request",
+    with patch("pyplumio.devices.ecomax.EcoMAX.wait_for"), patch(
+        "pyplumio.devices.ecomax.EcoMAX.request",
         side_effect=(True, True, True, True, True, True, True, True),
-    ) as mock_make_request:
+    ) as mock_request:
         await ecomax.async_setup()
         await ecomax.wait_until_done()
 
-    assert await ecomax.get_value(ATTR_LOADED)
-    assert mock_make_request.await_count == len(DATA_FRAME_TYPES)
+    assert await ecomax.get(ATTR_LOADED)
+    assert mock_request.await_count == len(DATA_FRAME_TYPES)
 
 
 async def test_async_setup_error(caplog) -> None:
     """Test with error during requesting initial data frames."""
     ecomax = EcoMAX(asyncio.Queue(), network=NetworkInfo())
 
-    with patch(
-        "pyplumio.devices.ecomax.EcoMAX.make_request",
+    with patch("pyplumio.devices.ecomax.EcoMAX.wait_for"), patch(
+        "pyplumio.devices.ecomax.EcoMAX.request",
         side_effect=(ValueError("test"), True, True, True, True, True, True, True),
-    ) as mock_make_request:
+    ) as mock_request:
         await ecomax.async_setup()
         await ecomax.wait_until_done()
 
     assert "Request failed" in caplog.text
-    assert not await ecomax.get_value(ATTR_LOADED)
-    assert mock_make_request.await_count == len(DATA_FRAME_TYPES)
+    assert not await ecomax.get(ATTR_LOADED)
+    assert mock_request.await_count == len(DATA_FRAME_TYPES)
 
 
 async def test_frame_versions_update(
-    ecomax: EcoMAX, messages: dict[int, bytearray]
+    ecomax: EcoMAX, messages: dict[FrameType, bytearray]
 ) -> None:
     """Test requesting updated frames."""
     with patch("asyncio.Queue.put_nowait") as mock_put_nowait:
@@ -156,17 +213,17 @@ async def test_frame_versions_update(
 
 
 async def test_ecomax_data_callbacks(
-    ecomax: EcoMAX, messages: dict[int, bytearray]
+    ecomax: EcoMAX, messages: dict[FrameType, bytearray]
 ) -> None:
-    """Test callbacks that are fired on received data frames."""
+    """Test callbacks that are dispatchd on received data frames."""
     ecomax.handle_frame(
         SensorDataMessage(message=messages[FrameType.MESSAGE_SENSOR_DATA])
     )
     await ecomax.wait_until_done()
-    heating_target = await ecomax.get_value("heating_target")
+    heating_target = await ecomax.get("heating_target")
     assert heating_target == 41.0
 
-    ecomax_control = await ecomax.get_parameter(ATTR_ECOMAX_CONTROL)
+    ecomax_control = await ecomax.get(ATTR_ECOMAX_CONTROL)
     assert isinstance(ecomax_control, EcomaxBinaryParameter)
     assert isinstance(ecomax_control.request, EcomaxControlRequest)
     assert ecomax_control.value == STATE_OFF
@@ -174,25 +231,25 @@ async def test_ecomax_data_callbacks(
 
 
 async def test_ecomax_parameters_callbacks(
-    ecomax: EcoMAX, messages: dict[int, bytearray]
+    ecomax: EcoMAX, messages: dict[FrameType, bytearray]
 ) -> None:
-    """Test callbacks that are fired on received parameter frames."""
+    """Test callbacks that are dispatchd on received parameter frames."""
     ecomax.handle_frame(
         EcomaxParametersResponse(message=messages[FrameType.RESPONSE_ECOMAX_PARAMETERS])
     )
     await ecomax.wait_until_done()
-    fuzzy_logic = await ecomax.get_parameter("fuzzy_logic")
+    fuzzy_logic = await ecomax.get("fuzzy_logic")
     assert isinstance(fuzzy_logic, EcomaxBinaryParameter)
     assert isinstance(fuzzy_logic.request, SetEcomaxParameterRequest)
     assert fuzzy_logic.value == STATE_ON
-    fuzzy_logic_value = await ecomax.get_value("fuzzy_logic")
+    fuzzy_logic_value = await ecomax.get("fuzzy_logic")
     assert fuzzy_logic_value == STATE_ON
     assert fuzzy_logic.request.data == {
         ATTR_INDEX: 18,
         ATTR_VALUE: 1,
     }
 
-    airflow_power_50 = await ecomax.get_parameter("airflow_power_50")
+    airflow_power_50 = await ecomax.get("airflow_power_50")
     assert airflow_power_50.value == 60.0
     assert airflow_power_50.min_value == 41.0
     assert airflow_power_50.max_value == 60.0
@@ -200,11 +257,11 @@ async def test_ecomax_parameters_callbacks(
 
 @patch("time.time", side_effect=(0, 10, 600, 610))
 async def test_fuel_consumption_callbacks(mock_time, caplog) -> None:
-    """Test callbacks that are fired on received fuel consumption."""
+    """Test callbacks that are dispatchd on received fuel consumption."""
     ecomax = EcoMAX(asyncio.Queue(), network=NetworkInfo())
     ecomax.handle_frame(Response(data={ATTR_FUEL_CONSUMPTION: 3.6}))
     await ecomax.wait_until_done()
-    fuel_burned = await ecomax.get_value(ATTR_FUEL_BURNED)
+    fuel_burned = await ecomax.get(ATTR_FUEL_BURNED)
     assert fuel_burned == 0.01
     ecomax.handle_frame(Response(data={ATTR_FUEL_CONSUMPTION: 1}))
     await ecomax.wait_until_done()
@@ -212,9 +269,9 @@ async def test_fuel_consumption_callbacks(mock_time, caplog) -> None:
 
 
 async def test_regdata_callbacks(
-    ecomax: EcoMAX, messages: dict[int, bytearray]
+    ecomax: EcoMAX, messages: dict[FrameType, bytearray]
 ) -> None:
-    """Test callbacks that are fired on received regdata."""
+    """Test callbacks that are dispatchd on received regdata."""
     ecomax.handle_frame(
         DataSchemaResponse(message=messages[FrameType.RESPONSE_DATA_SCHEMA])
     )
@@ -222,18 +279,19 @@ async def test_regdata_callbacks(
         RegulatorDataMessage(message=messages[FrameType.MESSAGE_REGULATOR_DATA])
     )
     await ecomax.wait_until_done()
-    regdata = await ecomax.get_value(ATTR_REGDATA)
-    assert regdata[1792] == 0
-    assert round(regdata[1024], 1) == 22.4
-    assert regdata[1280] == 41
-    assert regdata[183] == "0.0.0.0"
-    assert regdata[184] == "255.255.255.0"
+    regdata = await ecomax.get(ATTR_REGDATA)
+    assert isinstance(regdata, RegulatorData)
+    assert regdata.data[1792] == 0
+    assert round(regdata.data[1024], 1) == 22.4
+    assert regdata.data[1280] == 41
+    assert regdata.data[183] == "0.0.0.0"
+    assert regdata.data[184] == "255.255.255.0"
 
 
 async def test_regdata_callbacks_without_schema(
-    ecomax: EcoMAX, messages: dict[int, bytearray]
+    ecomax: EcoMAX, messages: dict[FrameType, bytearray]
 ) -> None:
-    """Test callbacks that are fired on received regdata."""
+    """Test callbacks that are dispatchd on received regdata."""
     ecomax.handle_frame(
         RegulatorDataMessage(message=messages[FrameType.MESSAGE_REGULATOR_DATA])
     )
@@ -243,14 +301,14 @@ async def test_regdata_callbacks_without_schema(
 
 
 async def test_mixer_sensors_callbacks(
-    ecomax: EcoMAX, messages: dict[int, bytearray]
+    ecomax: EcoMAX, messages: dict[FrameType, bytearray]
 ) -> None:
-    """Test callbacks that are fired on receiving mixer sensors info."""
+    """Test callbacks that are dispatchd on receiving mixer sensors info."""
     ecomax.handle_frame(
         SensorDataMessage(message=messages[FrameType.MESSAGE_SENSOR_DATA])
     )
     await ecomax.wait_until_done()
-    mixers = await ecomax.get_value(ATTR_MIXERS)
+    mixers = await ecomax.get(ATTR_MIXERS)
     assert len(mixers) == 1
     mixer = mixers[4]
     assert isinstance(mixer, Mixer)
@@ -259,14 +317,14 @@ async def test_mixer_sensors_callbacks(
 
 
 async def test_thermostat_sensors_callbacks(
-    ecomax: EcoMAX, messages: dict[int, bytearray]
+    ecomax: EcoMAX, messages: dict[FrameType, bytearray]
 ) -> None:
-    """Test callbacks that are fired on receiving thermostat sensors info."""
+    """Test callbacks that are dispatchd on receiving thermostat sensors info."""
     ecomax.handle_frame(
         SensorDataMessage(message=messages[FrameType.MESSAGE_SENSOR_DATA])
     )
     await ecomax.wait_until_done()
-    thermostats = await ecomax.get_value(ATTR_THERMOSTATS)
+    thermostats = await ecomax.get(ATTR_THERMOSTATS)
     assert len(thermostats) == 1
     thermostat = thermostats[0]
     assert isinstance(thermostat, Thermostat)
@@ -278,14 +336,14 @@ async def test_thermostat_sensors_callbacks(
         "contacts": True,
         "schedule": False,
     }
-    thermostat_count = await ecomax.get_value(ATTR_THERMOSTAT_COUNT)
+    thermostat_count = await ecomax.get(ATTR_THERMOSTAT_COUNT)
     assert thermostat_count == 1
 
 
 async def test_thermostat_parameters_callbacks(
-    ecomax: EcoMAX, messages: dict[int, bytearray]
+    ecomax: EcoMAX, messages: dict[FrameType, bytearray]
 ) -> None:
-    """Test callbacks that are fired on receiving thermostat parameters."""
+    """Test callbacks that are dispatchd on receiving thermostat parameters."""
     ecomax.handle_frame(Response(data={ATTR_THERMOSTAT_COUNT: 3}))
     ecomax.handle_frame(
         ThermostatParametersResponse(
@@ -293,11 +351,11 @@ async def test_thermostat_parameters_callbacks(
         )
     )
     await ecomax.wait_until_done()
-    thermostats = await ecomax.get_value(ATTR_THERMOSTATS)
+    thermostats = await ecomax.get(ATTR_THERMOSTATS)
     assert len(thermostats) == 1
     thermostat = thermostats[0]
     assert len(thermostat.data) == 12
-    party_target_temp = await thermostat.get_parameter("party_target_temp")
+    party_target_temp = await thermostat.get("party_target_temp")
     assert isinstance(party_target_temp, ThermostatParameter)
     assert isinstance(party_target_temp.request, SetThermostatParameterRequest)
     assert isinstance(party_target_temp.device, Thermostat)
@@ -314,9 +372,9 @@ async def test_thermostat_parameters_callbacks(
 
 
 async def test_thermostat_parameters_callbacks_without_thermostats(
-    ecomax: EcoMAX, messages: dict[int, bytearray]
+    ecomax: EcoMAX, messages: dict[FrameType, bytearray]
 ) -> None:
-    """Test callbacks that are fired on receiving thermostat parameters
+    """Test callbacks that are dispatchd on receiving thermostat parameters
     without any thermostats."""
     ecomax.handle_frame(Response(data={ATTR_THERMOSTAT_COUNT: 0}))
     ecomax.handle_frame(
@@ -325,15 +383,15 @@ async def test_thermostat_parameters_callbacks_without_thermostats(
         )
     )
     await ecomax.wait_until_done()
-    assert not await ecomax.get_value(ATTR_THERMOSTAT_PARAMETERS)
-    thermostat_profile = await ecomax.get_value(ATTR_THERMOSTAT_PROFILE)
+    assert not await ecomax.get(ATTR_THERMOSTAT_PARAMETERS)
+    thermostat_profile = await ecomax.get(ATTR_THERMOSTAT_PROFILE)
     assert thermostat_profile is None
 
 
 async def test_thermostat_profile_callbacks(
-    ecomax: EcoMAX, messages: dict[int, bytearray]
+    ecomax: EcoMAX, messages: dict[FrameType, bytearray]
 ) -> None:
-    """Test callbacks that are fired on receiving thermostat profile."""
+    """Test callbacks that are dispatchd on receiving thermostat profile."""
     ecomax.handle_frame(Response(data={ATTR_THERMOSTAT_COUNT: 3}))
     ecomax.handle_frame(
         ThermostatParametersResponse(
@@ -341,7 +399,7 @@ async def test_thermostat_profile_callbacks(
         )
     )
     await ecomax.wait_until_done()
-    thermostat_profile = await ecomax.get_parameter(ATTR_THERMOSTAT_PROFILE)
+    thermostat_profile = await ecomax.get(ATTR_THERMOSTAT_PROFILE)
     assert thermostat_profile.value == 0.0
     assert thermostat_profile.min_value == 0.0
     assert thermostat_profile.max_value == 5.0
@@ -356,22 +414,22 @@ async def test_thermostat_profile_callbacks(
     # Test when thermostat profile is none.
     ecomax.handle_frame(Response(data={ATTR_THERMOSTAT_PROFILE: None}))
     await ecomax.wait_until_done()
-    assert await ecomax.get_value(ATTR_THERMOSTAT_PROFILE) is None
+    assert await ecomax.get(ATTR_THERMOSTAT_PROFILE) is None
 
 
 async def test_mixer_parameters_callbacks(
-    ecomax: EcoMAX, messages: dict[int, bytearray]
+    ecomax: EcoMAX, messages: dict[FrameType, bytearray]
 ) -> None:
-    """Test callbacks that are fired on receiving mixer parameters."""
+    """Test callbacks that are dispatchd on receiving mixer parameters."""
     ecomax.handle_frame(
         MixerParametersResponse(message=messages[FrameType.RESPONSE_MIXER_PARAMETERS])
     )
     await ecomax.wait_until_done()
-    mixers = await ecomax.get_value(ATTR_MIXERS)
+    mixers = await ecomax.get(ATTR_MIXERS)
     assert len(mixers) == 1
     mixer = mixers[0]
     assert len(mixer.data) == 6
-    mixer_target_temp = await mixer.get_parameter("mixer_target_temp")
+    mixer_target_temp = await mixer.get("mixer_target_temp")
     assert isinstance(mixer_target_temp, MixerParameter)
     assert isinstance(mixer_target_temp.request, SetMixerParameterRequest)
     assert isinstance(mixer_target_temp.device, Mixer)
@@ -384,11 +442,11 @@ async def test_mixer_parameters_callbacks(
         ATTR_DEVICE_INDEX: 0,
     }
 
-    weather_control = await mixer.get_parameter("weather_control")
+    weather_control = await mixer.get("weather_control")
     assert isinstance(weather_control, MixerBinaryParameter)
     assert weather_control.value == STATE_ON
 
-    heat_curve = await mixer.get_parameter("heat_curve")
+    heat_curve = await mixer.get("heat_curve")
     assert isinstance(heat_curve, MixerParameter)
     assert heat_curve.value == 1.3
     assert heat_curve.min_value == 1.0
@@ -399,28 +457,28 @@ async def test_mixer_parameters_callbacks_without_mixers(ecomax: EcoMAX) -> None
     """Test mixer parameters callbacks without any mixers."""
     ecomax.handle_frame(MixerParametersResponse(data={ATTR_MIXER_PARAMETERS: None}))
     await ecomax.wait_until_done()
-    assert not await ecomax.get_value(ATTR_MIXER_PARAMETERS)
+    assert not await ecomax.get(ATTR_MIXER_PARAMETERS)
 
 
 async def test_schedule_callback(
-    ecomax: EcoMAX, messages: dict[int, bytearray], data: dict[int, DeviceDataType]
+    ecomax: EcoMAX,
+    messages: dict[FrameType, bytearray],
+    data: dict[FrameType, EventDataType],
 ) -> None:
-    """Test callback that is fired on receiving schedule data."""
+    """Test callback that is dispatchd on receiving schedule data."""
     ecomax.handle_frame(
         SchedulesResponse(message=messages[FrameType.RESPONSE_SCHEDULES])
     )
-    schedules = await ecomax.get_value(ATTR_SCHEDULES)
+    schedules = await ecomax.get(ATTR_SCHEDULES)
     assert len(schedules) == 1
     heating_schedule = schedules["heating"]
     assert isinstance(heating_schedule, Schedule)
 
-    heating_schedule_switch = await ecomax.get_parameter("heating_schedule_switch")
+    heating_schedule_switch = await ecomax.get("heating_schedule_switch")
     assert heating_schedule_switch.value == STATE_OFF
     assert isinstance(heating_schedule_switch, ScheduleBinaryParameter)
 
-    heating_schedule_parameter = await ecomax.get_parameter(
-        "heating_schedule_parameter"
-    )
+    heating_schedule_parameter = await ecomax.get("heating_schedule_parameter")
     assert isinstance(heating_schedule_parameter, ScheduleParameter)
     assert isinstance(heating_schedule_parameter.request, SetScheduleRequest)
     assert heating_schedule_parameter.value == 5
@@ -441,100 +499,33 @@ async def test_schedule_callback(
         assert schedule.intervals == schedule_data[index]
 
 
-async def test_subscribe(ecomax: EcoMAX, messages: dict[int, bytearray]) -> None:
-    """Test subscribing callback."""
-    mock_callback = AsyncMock(return_value=None)
-    ecomax.subscribe("heating_target", mock_callback)
-    ecomax.handle_frame(
-        SensorDataMessage(message=messages[FrameType.MESSAGE_SENSOR_DATA])
-    )
-    await ecomax.wait_until_done()
-    mock_callback.assert_awaited_once_with(41)
-    mock_callback.reset_mock()
-
-    # Test with change.
-    ecomax.handle_frame(Response(data={ATTR_SENSORS: {"heating_target": 45}}))
-    await ecomax.wait_until_done()
-    mock_callback.assert_awaited_once_with(45)
-    mock_callback.reset_mock()
-
-    # Remove the callback and make sure it doesn't fire again.
-    ecomax.unsubscribe("heating_target", mock_callback)
-    ecomax.handle_frame(Response(data={ATTR_SENSORS: {"heating_target": 50}}))
-    await ecomax.wait_until_done()
-    mock_callback.assert_not_awaited()
-
-
-async def test_subscribe_once(ecomax: EcoMAX, messages: dict[int, bytearray]) -> None:
-    """Test subscribing callback once."""
-    mock_callback = AsyncMock(return_value=None)
-    ecomax.subscribe_once("heating_target", mock_callback)
-    ecomax.handle_frame(
-        SensorDataMessage(message=messages[FrameType.MESSAGE_SENSOR_DATA])
-    )
-    await ecomax.wait_until_done()
-    mock_callback.assert_awaited_once_with(41)
-    mock_callback.reset_mock()
-
-    # Check that callback is not awaited on subsequent calls.
-    ecomax.handle_frame(
-        SensorDataMessage(message=messages[FrameType.MESSAGE_SENSOR_DATA])
-    )
-    await ecomax.wait_until_done()
-    mock_callback.assert_not_awaited()
-
-
-async def test_wait_for(ecomax: EcoMAX) -> None:
-    """Test waiting for value."""
-    mock_event = Mock(spec=asyncio.Event)
-    with pytest.raises(KeyError), patch(
-        "pyplumio.devices.Device.create_event", return_value=mock_event
-    ) as mock_create_event:
-        mock_event.wait = AsyncMock()
-        await ecomax.get_value("foo")
-
-    mock_create_event.assert_called_once_with("foo")
-    mock_event.wait.assert_awaited_once()
-
-
-async def test_get_value(ecomax: EcoMAX, messages: dict[int, bytearray]) -> None:
-    """Test getting the value from device data."""
-    ecomax.handle_frame(
-        SensorDataMessage(message=messages[FrameType.MESSAGE_SENSOR_DATA])
-    )
-    await ecomax.wait_until_done()
-
-    heating_temp = await ecomax.get_value("heating_temp")
-    assert round(heating_temp, 1) == 22.4
-
-
-async def test_make_request(ecomax: EcoMAX) -> None:
+async def test_request(ecomax: EcoMAX) -> None:
     """Test requesting the value."""
 
     with patch(
-        "pyplumio.devices.ecomax.EcoMAX.get_value",
+        "pyplumio.devices.ecomax.EcoMAX.get",
         side_effect=(asyncio.TimeoutError, True),
-    ) as mock_get_value, patch("asyncio.Queue.put_nowait") as mock_put_nowait:
-        assert await ecomax.make_request("foo", FrameType.REQUEST_ALERTS, timeout=5)
+    ) as mock_get, patch("asyncio.Queue.put_nowait") as mock_put_nowait:
+        assert await ecomax.request("foo", FrameType.REQUEST_ALERTS, timeout=5)
 
-    mock_get_value.assert_awaited_with("foo", timeout=5)
+    mock_get.assert_awaited_with("foo", timeout=5)
     assert mock_put_nowait.call_count == 2
     args, _ = mock_put_nowait.call_args
     assert isinstance(args[0], AlertsRequest)
 
 
-async def test_make_request_error(ecomax: EcoMAX) -> None:
+async def test_request_error(ecomax: EcoMAX) -> None:
     """Test requesting the value with error."""
     with patch(
-        "pyplumio.devices.ecomax.EcoMAX.get_value",
+        "pyplumio.devices.ecomax.EcoMAX.get",
         side_effect=(asyncio.TimeoutError, asyncio.TimeoutError),
     ), pytest.raises(ValueError):
-        await ecomax.make_request("foo", FrameType.REQUEST_ALERTS, retries=1)
+        await ecomax.request("foo", FrameType.REQUEST_ALERTS, retries=1)
 
 
 @patch("pyplumio.helpers.parameter.Parameter.is_changed", False)
-async def test_set_value(ecomax: EcoMAX, messages: dict[int, bytearray]) -> None:
-    """Test setting parameter value via set_value helper."""
+async def test_set(ecomax: EcoMAX, messages: dict[FrameType, bytearray]) -> None:
+    """Test setting parameter value via set helper."""
     ecomax.handle_frame(
         EcomaxParametersResponse(message=messages[FrameType.RESPONSE_ECOMAX_PARAMETERS])
     )
@@ -549,52 +540,34 @@ async def test_set_value(ecomax: EcoMAX, messages: dict[int, bytearray]) -> None
     )
 
     # Test setting an ecomax parameter.
-    assert await ecomax.set_value("fuel_flow_kg_h", 13.0)
-    fuel_flow_kg_h = await ecomax.get_value("fuel_flow_kg_h")
-    assert fuel_flow_kg_h == 13.0
+    assert await ecomax.set("fuel_flow_kg_h", 13.0)
+    fuel_flow_kg_h = await ecomax.get("fuel_flow_kg_h")
+    assert fuel_flow_kg_h.value == 13.0
 
     # Test setting an ecomax parameter without blocking.
-    with patch("pyplumio.devices.Device.set_value", new_callable=Mock), patch(
+    with patch("pyplumio.devices.Device.set", new_callable=Mock), patch(
         "pyplumio.helpers.task_manager.TaskManager.create_task"
     ) as mock_create_task:
-        ecomax.set_value_nowait("fuel_flow_kg_h", 10)
+        ecomax.set_nowait("fuel_flow_kg_h", 10)
 
     mock_create_task.assert_called_once()
 
     # Test setting a thermostat parameter.
     thermostat = ecomax.data[ATTR_THERMOSTATS][0]
-    assert await thermostat.set_value("party_target_temp", 21.0)
-    target_party_temp = await thermostat.get_value("party_target_temp")
-    assert target_party_temp == 21.0
+    assert await thermostat.set("party_target_temp", 21.0)
+    target_party_temp = await thermostat.get("party_target_temp")
+    assert target_party_temp.value == 21.0
 
     # Test setting a mixer parameter.
     mixer = ecomax.data[ATTR_MIXERS][0]
-    assert await mixer.set_value("mixer_target_temp", 35.0)
-    mixer_target_temp = await mixer.get_value("mixer_target_temp")
-    assert mixer_target_temp == 35.0
+    assert await mixer.set("mixer_target_temp", 35.0)
+    mixer_target_temp = await mixer.get("mixer_target_temp")
+    assert mixer_target_temp.value == 35.0
 
     # Test with invalid parameter.
     ecomax.data["bar"] = Mock()
     with pytest.raises(ParameterNotFoundError):
-        await ecomax.set_value("bar", 1)
-
-
-async def test_get_parameter(ecomax: EcoMAX) -> None:
-    """Test getting parameter from device."""
-    mock_event = Mock(spec=asyncio.Event)
-    with pytest.raises(KeyError), patch(
-        "pyplumio.devices.Device.create_event", return_value=mock_event
-    ) as mock_create_event:
-        mock_event.wait = AsyncMock()
-        await ecomax.get_parameter("foo")
-
-    mock_create_event.assert_called_once_with("foo")
-    mock_event.wait.assert_awaited_once()
-
-    # Test with invalid parameter.
-    ecomax.data["bar"] = Mock()
-    with pytest.raises(ParameterNotFoundError):
-        await ecomax.get_parameter("bar")
+        await ecomax.set("bar", 1)
 
 
 async def test_turn_on_off(ecomax: EcoMAX, caplog) -> None:
@@ -615,7 +588,7 @@ async def test_turn_on_off(ecomax: EcoMAX, caplog) -> None:
     ecomax.data[ATTR_ECOMAX_CONTROL].turn_off.assert_awaited_once()
 
 
-async def test_shutdown(ecomax: EcoMAX, messages: dict[int, bytearray]) -> None:
+async def test_shutdown(ecomax: EcoMAX, messages: dict[FrameType, bytearray]) -> None:
     """Test device tasks shutdown."""
     ecomax.handle_frame(
         SensorDataMessage(message=messages[FrameType.MESSAGE_SENSOR_DATA])
